pub struct RepoInfo {Show 26 fields
pub branch: Option<String>,
pub head: Option<HeadInfo>,
pub remotes: TabData<Vec<RemoteInfo>>,
pub upstream: Option<String>,
pub summary: RepoSummary,
pub changes: WorktreeChanges,
pub commits: Vec<CommitEntry>,
pub graph_lines: TabData<Vec<GraphLine>>,
pub local_branches: TabData<Vec<BranchInfo>>,
pub remote_branches: TabData<Vec<BranchInfo>>,
pub local_tags: TabData<Vec<BranchInfo>>,
pub remote_tags: TabData<Vec<BranchInfo>>,
pub remote_tags_loaded: bool,
pub remote_tags_attempted: bool,
pub files: TabData<Vec<String>>,
pub stashes: TabData<Vec<StashInfo>>,
pub worktrees: TabData<Vec<WorktreeInfo>>,
pub submodules: TabData<Vec<SubmoduleInfo>>,
pub reflog: TabData<Vec<ReflogEntry>>,
pub committer_stats: TabData<Vec<CommitterStat>>,
pub committer_stats_limit_reached: bool,
pub tab_loaded_at: [Option<Instant>; 10],
pub tab_loading: [bool; 10],
pub lfs_files: HashSet<String>,
pub lfs_installed: bool,
pub lfs_storage_size: Option<u64>,
}Fields
branch: Option<String>head: Option<HeadInfo>remotes: TabData<Vec<RemoteInfo>>upstream: Option<String>Configured upstream branch (e.g. “origin/main”) if HEAD tracks one.
summary: RepoSummarychanges: WorktreeChangesFile-level changes, populated by collect_info for the Detail view.
commits: Vec<CommitEntry>Recent commits in this repository.
graph_lines: TabData<Vec<GraphLine>>Graph view lines for the repository.
local_branches: TabData<Vec<BranchInfo>>Local branches in the repository.
remote_branches: TabData<Vec<BranchInfo>>Remote branches in the repository.
Local tags in the repository.
Remote tags in the repository.
Whether remote tags have been loaded from the remote repository.
Whether a remote tag fetch has been attempted in this session.
files: TabData<Vec<String>>Tracked files in the repository.
stashes: TabData<Vec<StashInfo>>Available stashes in the repository.
worktrees: TabData<Vec<WorktreeInfo>>Available worktrees in the repository.
submodules: TabData<Vec<SubmoduleInfo>>Configured submodules in the repository.
reflog: TabData<Vec<ReflogEntry>>Available reflog entries.
committer_stats: TabData<Vec<CommitterStat>>Committer statistics.
committer_stats_limit_reached: boolWhether the committer statistics walk was capped by the limit.
tab_loaded_at: [Option<Instant>; 10]Timestamps when each tab was loaded (index matches tab_idx)
tab_loading: [bool; 10]Whether each tab is currently loading in the background (index matches tab_idx)
lfs_files: HashSet<String>Files tracked by Git LFS in the index/working copy.
lfs_installed: boolWhether git-lfs is installed in the system PATH.
lfs_storage_size: Option<u64>Storage size of the local LFS directory if LFS is used.